==> prestashop_1.4.6.1.zip: prestashop/translations/de/pdf.php <==
<?php

global $_LANGPDF;
$_LANGPDF = array();
$_LANGPDF['PDF_invoicee0036b67b754e9f6442f9f9e6b200c33'] = 'Rücksendung Nr.';
$_LANGPDF['PDF_invoice77c3e447f60541a1c346a08134078c7f'] = 'Guthaben Nr.';
$_LANGPDF['PDF_invoicecb5efbba6a6babef9082ca6976928ca7'] = 'Lieferschein Nr.';
$_LANGPDF['PDF_invoicefe4da50838bb10dcbf1bf8dcd9b12ab5'] = 'Rechnung Nr.';
$_LANGPDF['PDF_invoiceba160acb58001c904c57507da3689265'] = 'Bestellung Nr.';
$_LANGPDF['PDF_invoice808a04117534f9dfb63b9accd7efc609'] = 'Firmensitz';
$_LANGPDF['PDF_invoicea54cedc1e053a70d4a6319feccf531ca'] = 'Telefonnr.:';
$_LANGPDF['PDF_invoice2babe53026309ed1bc4d26626dbaf9b3'] = 'Details:';
$_LANGPDF['PDF_invoice15b57bef332e7e0327d89fe93711a954'] = 'Eine elektronische Version steht auf Ihrem Konto bereit. Um auf Sie zuzugreifen, melden Sie sich bitte auf der Webseite';
$_LANGPDF['PDF_invoiceb1fb57b55075a4a51cf83e44d0440358'] = 'mit Ihren Zugangsdaten an (die Sie bei Ihrer ersten Bestellung erhalten haben).';
$_LANGPDF['PDF_invoiced98a07f84921b24ee30f86fd8cd85c3c'] = 'vom';
$_LANGPDF['PDF_invoice88be9ea838e21273267409d76af3b284'] = 'Wir haben Ihre Bitte um Rücksendung gespeichert.';
$_LANGPDF['PDF_invoicedd0b8feb4eb6c389c284518f5683017c'] = 'Wir erinnern Sie daran, dass Ihr Paket innerhalb von  ';
$_LANGPDF['PDF_invoiceea62a2e28a800c367509773730120a67'] = 'Tagen nach Erhalt Ihrer Bestellung an uns zurückgesendet werden muss.';
$_LANGPDF['PDF_invoice3d2f834cf879baebfdbe52c1c14d9d53'] = 'Liste der Produkte, die zurückgesendet werden:';
$_LANGPDF['PDF_invoice9fad4fa5f3fa5caad9b506bbdd9f35d4'] = 'Ihre Rücksendenummer:';
$_LANGPDF['PDF_invoicefb902bc4807c307b9309f2b528b96f2b'] = 'Rücksendung';
$_LANGPDF['PDF_invoiceec9d9f81be48dabb74bcdad5312816af'] = 'Bitte sorgen Sie dafür, dass diese Nummer auf Ihrem Rücksendepaket steht.';
$_LANGPDF['PDF_invoicefbbd47b7e45c0ad3fe0bf70539b5a2d4'] = 'ERINNERUNG:';
$_LANGPDF['PDF_invoicea3852e23346f6f1e29e1683991690af3'] = '- Alle Produkte müssen in ihrer Originalverpackung und im ursprünglichen Zustand zurückgeschickt werden.';
$_LANGPDF['PDF_invoice0e9a828e54995e48083a072205493fb4'] = '- Bitte drucken Sie dieses Dokument aus und legen es Ihrem Paket bei.';
$_LANGPDF['PDF_invoicead500469c8dc258dcebb89c9efe15de7'] = '- Das Paket muss an folgende Adresse geschickt werden:';
$_LANGPDF['PDF_invoice9f68b11daca41ccf9fdc9d2f69901c9c'] = 'Nach Erhalt Ihres Pakets erstatten wir Ihnen dann den Betrag Ihrer Bestellung und benachrichtigen Sie per E-Mail darüber.';
$_LANGPDF['PDF_invoice2d0620950a4d96ae301ba7a98e528714'] = 'Bitte wenden Sie sich an uns, wenn Sie Fragen haben.';
$_LANGPDF['PDF_invoice25e12a86579549b9f88117615eb05e4b'] = 'Wenn die oben genannten Rücksendebedingungen nicht erfüllt wurden,';
$_LANGPDF['PDF_invoicec896fe3f3895e8ef54194eec601b8f3c'] = 'behalten wir uns das Recht vor, Ihr Paket oder Ihre Rückerstattung zu verweigern.';
$_LANGPDF['PDF_invoiceb5a7adde1af5c87d7fd797b6245c2a39'] = 'Beschreibung';
$_LANGPDF['PDF_invoice63d5049791d9d79d86e9a108b0a999ca'] = 'Referenz';
$_LANGPDF['PDF_invoice03ab340b3f99e03cff9e84314ead38c0'] = 'Menge';
$_LANGPDF['PDF_invoice396124314c5fd1fa5bf463274896dc80'] = 'Keine Methode zur Preisanzeige für diese Benutzergruppe definiert';
$_LANGPDF['PDF_invoice065ab3a28ca4f16f55f103adc7d0226f'] = 'Lieferung';
$_LANGPDF['PDF_invoice6bdf2efe1a99072849d4e87baee37dbe'] = 'Rechnungsstellung';
$_LANGPDF['PDF_invoice60da3bd6867e3952ef0057a0772ea885'] = 'Steuernummer:';
$_LANGPDF['PDF_invoice7b13afd12d6d91d52aa9f857d23f96ef'] = 'Rechnungsvorlage';
$_LANGPDF['PDF_invoiced1228f5476d15142b1358ae4b5fa2454'] = 'Bestellung Nr.';
$_LANGPDF['PDF_invoicef8617a92ba0a0a4eabee724eab7c9f48'] = 'Versanddienst:';
$_LANGPDF['PDF_invoicec1f6368d15f7c13c4e5e8f70c68c747f'] = 'Zahlungsweise:';
$_LANGPDF['PDF_invoicea3a79b28bc45b7fd393effd056b917e1'] = 'Absendedatum:';
$_LANGPDF['PDF_invoice115dfa9ced2cf136ae677b9a389a5e60'] = 'Geschenkverpackung';
$_LANGPDF['PDF_invoice2370a4958c4ebe6d6c8045cd49a6b392'] = 'Gesamtpreis exkl. USt.';
$_LANGPDF['PDF_invoiceebaee01719541f61281c16ba22ebbfde'] = 'Gesamtpreis inkl. USt.';
$_LANGPDF['PDF_invoicea0eb2cd0b3deb5444102e9a82edae11e'] = 'Gesamt Produkte';
$_LANGPDF['PDF_invoicef3e545fccad720e197b9ca3b8b658440'] = 'Gesamt Ermäßigungen inkl. USt.';
$_LANGPDF['PDF_invoice9cc000efe3e783af5bf114f2e6573156'] = 'Gesamtbetrag Geschenkverpackung';
$_LANGPDF['PDF_invoicef4e8b53a114e5a17d051ab84d326cae5'] = 'Gesamt Fremdleistung (Versand)';
$_LANGPDF['PDF_invoice96b0141273eabab320119c467cdcaf17'] = 'Gesamt';
$_LANGPDF['PDF_invoice54732c5d0a3f0d597312b0ee55d71fca'] = 'inkl. MwSt.';
$_LANGPDF['PDF_invoiceac5831c7ec2fed92c7bb73e9962003a4'] = 'exkl. MwSt.';
$_LANGPDF['PDF_invoiceafd42dfebce46ec93972b2e0cbb8b83f'] = 'Einzelpreis';
$_LANGPDF['PDF_invoice1d744a9ad1dac20645cfc4a36b77323b'] = 'Bild(er)';
$_LANGPDF['PDF_invoicec2808546f3e14d267d798f4e0e6f102e'] = 'Benutzerdefiniert';
$_LANGPDF['PDF_invoicea1e7379abfdbc3b8e03506e5489c6110'] = 'Ermäßigung:';
$_LANGPDF['PDF_invoicee7bbf027179f23c92bec649fa6ae78e4'] = 'Gemäß Artikel 196 i.V.m. Artikel 44 Richtlinie 2006/112/EG (MwStSystRL) schuldet der Empfänger dieser Dienstleistungen die Mehrwertsteuer gegenüber dem Fiskus.';
$_LANGPDF['PDF_invoice42c26bf38ece1dcd27aca8c6f8c076ed'] = 'Steuerdetails';
$_LANGPDF['PDF_invoice4b78ac8eb158840e9638a3aeb26c4a9d'] = 'Steuer';
$_LANGPDF['PDF_invoicecd6576cc33506a6c44e2debbde5c14d9'] = 'Gesamtpreis exkl. USt.';
$_LANGPDF['PDF_invoiceb602e0d0c6a72053d0a5be60cb2f8126'] = 'Gesamt Steuern';
$_LANGPDF['PDF_invoicefe1218d355367ae728ae5bf4bbf0019e'] = 'Ökosteuer (inkl. USt.)';
$_LANGPDF['PDF_invoiceae5c2883df7651730799e1036984a6a3'] = 'Gesamt inkl. USt.';
$_LANGPDF['PDF_invoice068f80c7519d0528fb08e82137a72131'] = 'Produkte';
$_LANGPDF['PDF_invoice914419aa32f04011357d3b604a86d7eb'] = 'Dienstleistungen (Versand)';
$_LANGPDF['PDF_invoice41c1d61bfff3fc9b1fd8f195061b8caa'] = 'Geschenkverpackung';
$_LANGPDF['PDF_invoice6f3455d187a23443796efdcbe044096b'] = 'Keine Steuer';

?>

==> prestashop_1.4.7.0.zip: prestashop/translations/de/pdf.php <==
<?php

global $_LANGPDF;
$_LANGPDF = array();
$_LANGPDF['PDF_invoicee0036b67b754e9f6442f9f9e6b200c33'] = 'Rücksendungs-Nr.';
$_LANGPDF['PDF_invoice77c3e447f60541a1c346a08134078c7f'] = 'Guthaben Nr.';
$_LANGPDF['PDF_invoicecb5efbba6a6babef9082ca6976928ca7'] = 'Lieferschein-Nr.';
$_LANGPDF['PDF_invoicefe4da50838bb10dcbf1bf8dcd9b12ab5'] = 'Rechnungs-Nr.';
$_LANGPDF['PDF_invoiceba160acb58001c904c57507da3689265'] = 'Bestell-Nr.';
$_LANGPDF['PDF_invoice808a04117534f9dfb63b9accd7efc609'] = 'Firmensitz';
$_LANGPDF['PDF_invoicea54cedc1e053a70d4a6319feccf531ca'] = 'Telefonnr.:';
$_LANGPDF['PDF_invoice2babe53026309ed1bc4d26626dbaf9b3'] = 'Details:';
$_LANGPDF['PDF_invoice15b57bef332e7e0327d89fe93711a954'] = 'Eine elektronische Version dieser Rechnun steht Ihnen in Ihrem Kundenkonto zur weiteren Verwendung bereit. Um die Rechnung einzusehen, melden Sie sich ';
$_LANGPDF['PDF_invoiceb1fb57b55075a4a51cf83e44d0440358'] = 'mit Ihren Zugangsdaten an (die Sie bei Ihrer ersten Bestellung erhalten haben).';
$_LANGPDF['PDF_invoiced98a07f84921b24ee30f86fd8cd85c3c'] = 'vom';
$_LANGPDF['PDF_invoice88be9ea838e21273267409d76af3b284'] = 'Wir haben Ihre Bitte um Rücksendung gespeichert.';
$_LANGPDF['PDF_invoicedd0b8feb4eb6c389c284518f5683017c'] = 'Wir erinnern Sie daran, dass Ihr Paket innerhalb von  ';
$_LANGPDF['PDF_invoiceea62a2e28a800c367509773730120a67'] = 'Tagen nach Erhalt Ihrer Bestellung an uns zurückgesendet werden muss.';
$_LANGPDF['PDF_invoice3d2f834cf879baebfdbe52c1c14d9d53'] = 'Liste der Produkte, die zurückgesendet werden:';
$_LANGPDF['PDF_invoice9fad4fa5f3fa5caad9b506bbdd9f35d4'] = 'Ihre Rücksendenummer:';
$_LANGPDF['PDF_invoicefb902bc4807c307b9309f2b528b96f2b'] = 'Rücksendung';
$_LANGPDF['PDF_invoiceec9d9f81be48dabb74bcdad5312816af'] = 'Bitte sorgen Sie dafür, dass diese Nummer auf Ihrem Rücksendepaket steht.';
$_LANGPDF['PDF_invoicefbbd47b7e45c0ad3fe0bf70539b5a2d4'] = 'ERINNERUNG:';
$_LANGPDF['PDF_invoicea3852e23346f6f1e29e1683991690af3'] = '- Alle Produkte müssen in ihrer Originalverpackung und im ursprünglichen Zustand zurückgeschickt werden.';
$_LANGPDF['PDF_invoice0e9a828e54995e48083a072205493fb4'] = '- Bitte drucken Sie dieses Dokument aus und legen es Ihrem Paket bei.';
$_LANGPDF['PDF_invoicead500469c8dc258dcebb89c9efe15de7'] = '- Das Paket muss an folgende Adresse geschickt werden:';
$_LANGPDF['PDF_invoice9f68b11daca41ccf9fdc9d2f69901c9c'] = 'Nach Erhalt Ihres Pakets erstatten wir Ihnen dann den Betrag Ihrer Bestellung und benachrichtigen Sie per E-Mail darüber.';
$_LANGPDF['PDF_invoice2d0620950a4d96ae301ba7a98e528714'] = 'Bitte wenden Sie sich an uns, wenn Sie Fragen haben.';
$_LANGPDF['PDF_invoice25e12a86579549b9f88117615eb05e4b'] = 'Wenn die oben genannten Rücksendebedingungen nicht erfüllt wurden,';
$_LANGPDF['PDF_invoicec896fe3f3895e8ef54194eec601b8f3c'] = 'behalten wir uns das Recht vor, Ihr Paket oder Ihre Rückerstattung zu verweigern.';
$_LANGPDF['PDF_invoiceb5a7adde1af5c87d7fd797b6245c2a39'] = 'Beschreibung';
$_LANGPDF['PDF_invoice63d5049791d9d79d86e9a108b0a999ca'] = 'Referenz';
$_LANGPDF['PDF_invoice03ab340b3f99e03cff9e84314ead38c0'] = 'Menge';
$_LANGPDF['PDF_invoice396124314c5fd1fa5bf463274896dc80'] = 'Keine Methode zur Preisanzeige für diese Benutzergruppe definiert';
$_LANGPDF['PDF_invoice065ab3a28ca4f16f55f103adc7d0226f'] = 'Lieferung';
$_LANGPDF['PDF_invoice6bdf2efe1a99072849d4e87baee37dbe'] = 'Rechnungsstellung';
$_LANGPDF['PDF_invoice60da3bd6867e3952ef0057a0772ea885'] = 'Steuernummer:';
$_LANGPDF['PDF_invoice7b13afd12d6d91d52aa9f857d23f96ef'] = 'Rechnungsvorlage';
$_LANGPDF['PDF_invoiced1228f5476d15142b1358ae4b5fa2454'] = 'Bestellung Nr.';
$_LANGPDF['PDF_invoicef8617a92ba0a0a4eabee724eab7c9f48'] = 'Versanddienst:';
$_LANGPDF['PDF_invoicec1f6368d15f7c13c4e5e8f70c68c747f'] = 'Zahlungsweise:';
$_LANGPDF['PDF_invoicea3a79b28bc45b7fd393effd056b917e1'] = 'Absendedatum:';
$_LANGPDF['PDF_invoice115dfa9ced2cf136ae677b9a389a5e60'] = 'Geschenkverpackung';
$_LANGPDF['PDF_invoice2370a4958c4ebe6d6c8045cd49a6b392'] = 'Gesamtpreis exkl. USt.';
$_LANGPDF['PDF_invoiceebaee01719541f61281c16ba22ebbfde'] = 'Gesamtpreis inkl. USt.';
$_LANGPDF['PDF_invoicea0eb2cd0b3deb5444102e9a82edae11e'] = 'Gesamt Produkte';
$_LANGPDF['PDF_invoicef3e545fccad720e197b9ca3b8b658440'] = 'Gesamt Ermäßigungen inkl. USt.';
$_LANGPDF['PDF_invoice9cc000efe3e783af5bf114f2e6573156'] = 'Gesamtbetrag Geschenkverpackung';
$_LANGPDF['PDF_invoicef4e8b53a114e5a17d051ab84d326cae5'] = 'Gesamt Fremdleistung (Versand)';
$_LANGPDF['PDF_invoice96b0141273eabab320119c467cdcaf17'] = 'Gesamt';
$_LANGPDF['PDF_invoice54732c5d0a3f0d597312b0ee55d71fca'] = 'inkl. MwSt.';
$_LANGPDF['PDF_invoiceac5831c7ec2fed92c7bb73e9962003a4'] = 'exkl. MwSt.';
$_LANGPDF['PDF_invoiceafd42dfebce46ec93972b2e0cbb8b83f'] = 'Einzelpreis';
$_LANGPDF['PDF_invoice1d744a9ad1dac20645cfc4a36b77323b'] = 'Bild(er)';
$_LANGPDF['PDF_invoicec2808546f3e14d267d798f4e0e6f102e'] = 'Benutzerdefiniert';
$_LANGPDF['PDF_invoicea1e7379abfdbc3b8e03506e5489c6110'] = 'Ermäßigung:';
$_LANGPDF['PDF_invoicee7bbf027179f23c92bec649fa6ae78e4'] = 'Gemäß Artikel 196 i.V.m. Artikel 44 Richtlinie 2006/112/EG (MwStSystRL) schuldet der Empfänger dieser Dienstleistungen die Mehrwertsteuer gegenüber dem Fiskus.';
$_LANGPDF['PDF_invoice42c26bf38ece1dcd27aca8c6f8c076ed'] = 'Steuerdetails';
$_LANGPDF['PDF_invoice4b78ac8eb158840e9638a3aeb26c4a9d'] = 'Steuer';
$_LANGPDF['PDF_invoicecd6576cc33506a6c44e2debbde5c14d9'] = 'Gesamtpreis exkl. USt.';
$_LANGPDF['PDF_invoiceb602e0d0c6a72053d0a5be60cb2f8126'] = 'Gesamt Steuern';
$_LANGPDF['PDF_invoicefe1218d355367ae728ae5bf4bbf0019e'] = 'Ökosteuer (inkl. USt.)';
$_LANGPDF['PDF_invoiceae5c2883df7651730799e1036984a6a3'] = 'Gesamt inkl. USt.';
$_LANGPDF['PDF_invoice068f80c7519d0528fb08e82137a72131'] = 'Produkte';
$_LANGPDF['PDF_invoice914419aa32f04011357d3b604a86d7eb'] = 'Dienstleistungen (Versand)';
$_LANGPDF['PDF_invoice41c1d61bfff3fc9b1fd8f195061b8caa'] = 'Geschenkverpackung';
$_LANGPDF['PDF_invoice6f3455d187a23443796efdcbe044096b'] = 'Keine Steuer';

?>
